function ret=BVdtistats();
%gets eigenvalue 1,2,3 from DDT file
%calculates Cl, Cp, Cs, radial diffusivity, relative anisotropy, eigenvalue maps and trace(D)
%input: DDT (from VDW) and FA map (vmp) output: 9 maps + FA map in DTISTATS.VMP.
%
%requires BVQXtools/Neuroelf to download from http://www.neuroelf.net

%(C) Pim Pullens - Brain Innovation BV - Maastricht NL
%20091106
%20091110 added eigen value maps
%20110309 added trace(D)

%Geometric measures as described in Westin C-F et al, Medical Image Analysis
%Volume 6, Issue 2, June 2002, Pages 93-108

%checking for bvqxtools
bv=bvqxtools_version;
version=str2num(bv(1:3));
release=bv(4);
if version<0.7 || version==0.7 && release <'f',
    disp('Please update BVQXtools, on http://wiki.brainvoyager.com/BVQXtools');
end

%finding lookup tables (LUTs) for color map
otype = ostype;
if otype.machine == 'WIN';
    LUTpath = 'C:\Program Files\BrainVoyager QX\MapLUTs';
    fs = otype.filesep;
else
    changeLUT = input('Changing map colors to LUT colors, ok? [y/n]','s');
    if changeLUT == 'y',
        disp('Specify LUT location (e.g. C:\Program Files\BrainVoyager QX\MapLUTs)');
        LUTpath = uigetdir('Please specify location of LUTs..');
        fs = otype.filesep;
    end
end

%load fa map for reference
disp('Load FA vmp for reference..');
fa=BVQXfile('*.vmp','Please select FA.vmp...');

%load ddt
disp('Load ddt tensor file..');
ddt=BVQXfile('*.ddt','Please select a DDT...');
tensor=ddt.TensorEigenVs;
%show tensor dims
disp(['Tensor dimensions: ', num2str(size(tensor))]);

%get eigs
disp('Getting eigenvalues from tensor..');
eig1=squeeze(tensor(10,:,:,:));
eig1=shiftdim(eig1,1);
dummy=zeros(size(eig1,2),size(eig1,1),size(eig1,3));
for i=1:size(eig1,3),
    dummy(:,:,i)=eig1(:,:,i)';
end
eig1=dummy;

eig2=squeeze(tensor(11,:,:,:));
eig2=shiftdim(eig2,1);
dummy=zeros(size(eig2,2),size(eig2,1),size(eig2,3));
for i=1:size(eig2,3),
    dummy(:,:,i)=eig2(:,:,i)';
end
eig2=dummy;

eig3=squeeze(tensor(12,:,:,:));
eig3=shiftdim(eig3,1);
dummy=zeros(size(eig3,2),size(eig3,1),size(eig3,3));
for i=1:size(eig3,3),
    dummy(:,:,i)=eig3(:,:,i)';
end
eig3=dummy;


%cl, cp, cs
disp('Computing geometrical measures Cl, Cp, Cs..');
cl=(eig1-eig2)./eig1;
cp=(eig2-eig3)./eig1;
cs=eig3./eig1;

%rd
disp('Computing radial diffusivity..');
rd=(eig2+eig3)/2;

%RA
disp('Computing relative anisotropy..');
ADC=(eig1+eig2+eig3)/3;
ra=sqrt((eig1-ADC).^2+(eig2-ADC).^2+(eig3-ADC).^2)./(sqrt(3)*ADC);

%eigs
disp('Creating Eigen value maps..')

%trace
disp('Creating Trace image..');
traceD = eig1+eig2+eig3;

%put in vmp
disp('Creating VMP maps..');
%create individual maps

for i=2:10,
    fa.Map(i)=fa.Map(1);
end

fa.Map(2).VMPData=eig1;
fa.Map(2).Name='Eigen value 1';
fa.Map(2).LowerThreshold=0;
fa.Map(2).UpperThreshold=0.001;
if changeLUT == 'y'
    fa.Map(2).LUTName=[LUTpath,fs,'bone.olt'];
else
    fa.Map(2).LutName = '<default>';
end

fa.Map(3).VMPData=eig2;
fa.Map(3).Name='Eigen value 2';
fa.Map(3).LowerThreshold=0;
fa.Map(3).UpperThreshold=0.001;
if changeLUT == 'y'
    fa.Map(3).LUTName=[LUTpath,fs,'bone.olt'];
else
    fa.Map(4).LutName = '<default>';
end

fa.Map(4).VMPData=eig3;
fa.Map(4).Name='Eigen value 3';
fa.Map(4).LowerThreshold=0;
fa.Map(4).UpperThreshold=0.001;
if changeLUT == 'y',
    fa.Map(4).LUTName=[LUTpath,fs,'bone.olt'];
else
    fa.Map(4).LutName = '<default>';
end

fa.Map(5).VMPData=cl;
fa.Map(5).Name='Linear measure Cl';
fa.Map(5).LowerThreshold=0.01;
fa.Map(5).UpperThreshold=1;
if changeLUT == 'y',
    fa.Map(5).LUTName=[LUTpath,fs,'hsv.olt'];
else
    fa.Map(5).LutName = '<default>';
end

fa.Map(6).VMPData=cp;
fa.Map(6).Name='Planar measure Cp';
fa.Map(6).LowerThreshold=0.01;
fa.Map(6).UpperThreshold=1;
if changeLUT == 'y',
    fa.Map(6).LUTName=[LUTpath,fs,'hsv.olt'];
else
    fa.Map(6).LutName = '<default>';
end

fa.Map(7).VMPData=cs;
fa.Map(7).Name='Spherical measure Cs';
fa.Map(7).LowerThreshold=0.01;
fa.Map(7).UpperThreshold=1;
if changeLUT == 'y',
    fa.Map(7).LUTName=[LUTpath,fs,'hsv.olt'];
else
    fa.Map(7).LutName = '<default>';
end

fa.Map(8).VMPData=rd;
fa.Map(8).Name='Radial diffusivity';
fa.Map(8).LowerThreshold=0;
fa.Map(8).UpperThreshold=0.001;
if changeLUT == 'y',
    fa.Map(8).LUTName=[LUTpath,fs,'<default>'];
else
    fa.Map(8).LutName = '<default>';
end

fa.Map(9).VMPData=ra;
fa.Map(9).Name='Relative anisotropy';
fa.Map(9).LowerThreshold=0.01;
fa.Map(9).UpperThreshold=1;
if changeLUT == 'y',
    fa.Map(9).LUTName=[LUTpath,fs,'<default>'];
else
    fa.Map(9).LutName = '<default>';
end

fa.Map(10).VMPData=traceD;
fa.Map(10).Name='Trace of Diffusion Tensor';
fa.Map(10).LowerThreshold=0;
fa.Map(10).UpperThreshold=0.001;
if changeLUT == 'y',
    fa.Map(10).LUTName=[LUTpath,fs,'bone.olt'];
else
    fa.Map(2).LutName = '<default>';
end

fa.SaveAs('DTISTATS.vmp');
disp('VMP saved as "DTISTATS.vmp"');
disp('Done.');
ret=1;